View Source GoogleApi.AddressValidation.V1.Model.GoogleMapsAddressvalidationV1ProvideValidationFeedbackRequest (google_api_address_validation v0.3.2)
The request for sending validation feedback.
Attributes
-
conclusion(type:String.t, default:nil) - Required. The outcome of the sequence of validation attempts. If this field is set toVALIDATION_CONCLUSION_UNSPECIFIED, anINVALID_ARGUMENTerror will be returned. -
responseId(type:String.t, default:nil) - Required. The ID of the response that this feedback is for. This should be the response_id from the first response in a series of address validation attempts.
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
Functions
Unwrap a decoded JSON object into its complex fields.