View Source GoogleApi.AddressValidation.V1.Model.GoogleMapsAddressvalidationV1Verdict (google_api_address_validation v0.3.2)
High level overview of the address validation result and geocode.
Attributes
-
addressComplete(type:boolean(), default:nil) - The address is considered complete if there are no unresolved tokens, no unexpected or missing address components. If unset, indicates that the value isfalse. Seemissing_component_types,unresolved_tokensorunexpectedfields for more details. -
geocodeGranularity(type:String.t, default:nil) - Information about the granularity of thegeocode. This can be understood as the semantic meaning of how coarse or fine the geocoded location is. This can differ from thevalidation_granularityabove occasionally. For example, our database might record the existence of an apartment number but do not have a precise location for the apartment within a big apartment complex. In that case, thevalidation_granularitywill beSUB_PREMISEbut thegeocode_granularitywill bePREMISE. -
hasInferredComponents(type:boolean(), default:nil) - At least one address component was inferred (added) that wasn't in the input, see [google.maps.addressvalidation.v1.Address.address_components] for details. -
hasReplacedComponents(type:boolean(), default:nil) - At least one address component was replaced, see [google.maps.addressvalidation.v1.Address.address_components] for details. -
hasUnconfirmedComponents(type:boolean(), default:nil) - At least one address component cannot be categorized or validated, see [google.maps.addressvalidation.v1.Address.address_components] for details. -
inputGranularity(type:String.t, default:nil) - The granularity of the input address. This is the result of parsing the input address and does not give any validation signals. For validation signals, refer tovalidation_granularitybelow. For example, if the input address includes a specific apartment number, then theinput_granularityhere will beSUB_PREMISE. If we cannot match the apartment number in the databases or the apartment number is invalid, thevalidation_granularitywill likely bePREMISEor below. -
validationGranularity(type:String.t, default:nil) - The granularity level that the API can fully validate the address to. For example, anvalidation_granularityofPREMISEindicates all address components at the level ofPREMISEor more coarse can be validated. Per address component validation result can be found in [google.maps.addressvalidation.v1.Address.address_components].
Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Types
@type t() :: %GoogleApi.AddressValidation.V1.Model.GoogleMapsAddressvalidationV1Verdict{ addressComplete: boolean() | nil, geocodeGranularity: String.t() | nil, hasInferredComponents: boolean() | nil, hasReplacedComponents: boolean() | nil, hasUnconfirmedComponents: boolean() | nil, inputGranularity: String.t() | nil, validationGranularity: String.t() | nil }
Functions
Unwrap a decoded JSON object into its complex fields.